#
# spec file for package alsa-plugins
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if %suse_version > 1030
%define build_pulse	1
%define build_speex	1
%else
%define build_pulse	0
%define build_speex	0
%endif

Name:           alsa-plugins
BuildRequires:  alsa-devel
BuildRequires:  dbus-1-devel
BuildRequires:  libjack-devel
BuildRequires:  libjack0
BuildRequires:  libsamplerate-devel
BuildRequires:  libtool
%if %build_pulse
BuildRequires:  libpulse-devel
%endif
%if %build_speex
BuildRequires:  speex-devel
%endif
%define package_version	1.0.27
Url:            http://www.alsa-project.org/
Summary:        Extra Plug-Ins for the ALSA Library
License:        LGPL-2.1+
Group:          System/Libraries
Version:        1.0.27
Release:        5.1
%ifarch s390x
Recommends:     %{name}-32bit = %{version}
%endif
Source:         ftp://ftp.alsa-project.org/pub/plugins/alsa-plugins-%{package_version}.tar.bz2
Source1:        asound-pulse.conf
Source2:        alsa-pulse.conf
Source3:        baselibs.conf
# upstream fixes
Patch1:         0001-Check-for-and-include-libavutil.h-to-avoid-unresolve.patch
Patch2:         0002-Add-AM_MAINTAINER_MODE-enable-to-configure.in.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package contains the extra plug-ins for the ALSA library.

%package jack
Summary:        JACK I/O Plug-In for the ALSA Library
License:        LGPL-2.1+
Group:          System/Libraries
Requires:       jack
%ifarch s390x
Recommends:     %{name}-jack-32bit = %{version}
%endif

%description jack
This package contains the JACK (Jack Audio Connection Kit) I/O plug-in
for the ALSA library.

%if %build_pulse

%package pulse
Summary:        Pulseaudio Plug-In for the ALSA Library
License:        GPL-2.0+ and LGPL-2.1+
Group:          System/Libraries
Requires:       pulseaudio
%ifarch s390x
Recommends:     %{name}-pulse-32bit = %{version}
%endif

%description pulse
pulseaudio is a networked sound server for Linux and other Unix like
operating systems and Microsoft Windows. It is intended to be an
improved drop-in replacement for the Enlightened Sound Daemon (ESOUND).

This package contains the polypaudio I/O plug-in for the ALSA library.

%endif

%package maemo
Summary:        Maemo Plug-Ins for the ALSA Library
License:        LGPL-2.1+
Group:          System/Libraries

%description maemo
This package contains the ALSA-library plug-ins using maemo SDK for
Nokia 770.

%package samplerate
Summary:        Samplerate Plug-In for the ALSA Library
License:        GPL-2.0+
Group:          System/Libraries
%ifarch s390x
Recommends:     %{name}-samplerate-32bit = %{version}
%endif

%description samplerate
This package contains the sample rate converter plugin for the ALSA
library using libsamplerate.

%if %build_speex

%package speex
Summary:        Speex Prerocessor Plug-In for the ALSA Library
License:        LGPL-2.1+
Group:          System/Libraries
%ifarch s390x
Recommends:     %{name}-speex-32bit = %{version}
%endif

%description speex
This package contains the Speex preprocessor plugin for the ALSA
library using libspeexdsp.

%endif

%prep
%setup -q -n %{name}-%{package_version}
%patch1 -p1
%patch2 -p1

%build
export AUTOMAKE_JOBS="%{?_smp_mflags}"
autoreconf -fi
%configure --enable-maemo-plugin --enable-maemo-resource-manager \
    --with-speex=builtin
make %{?_smp_mflags}

%install
%makeinstall
mkdir -p %{buildroot}/etc/
%if %build_pulse
%__install -m 0644 %_sourcedir/asound-pulse.conf %{buildroot}/etc/
%__install -m 0644 %_sourcedir/alsa-pulse.conf %{buildroot}/etc/
%endif
# modules don't need *.la files
rm -f $RPM_BUILD_ROOT%{_libdir}/alsa-lib/*.la

%post pulse
if type -p setup-pulseaudio > /dev/null; then
    setup-pulseaudio --auto
fi
exit 0

%postun pulse
if type -p setup-pulseaudio > /dev/null; then
    setup-pulseaudio --auto
fi
exit 0

%files
%defattr(-, root, root)
%doc COPYING
%doc doc/README-pcm-oss
%doc doc/README-arcam-av
%doc doc/upmix.txt
%doc doc/vdownmix.txt
%doc doc/speexrate.txt
%{_libdir}/alsa-lib/libasound_module_ctl_oss.so
%{_libdir}/alsa-lib/libasound_module_pcm_oss.so
%{_libdir}/alsa-lib/libasound_module_pcm_upmix.so
%{_libdir}/alsa-lib/libasound_module_pcm_vdownmix.so
%{_libdir}/alsa-lib/libasound_module_pcm_usb_stream.so
%{_libdir}/alsa-lib/libasound_module_rate_speexrate*.so
%{_libdir}/alsa-lib/libasound_module_ctl_arcam_av.so

%files jack
%defattr(-, root, root)
%doc COPYING
%doc doc/README-jack
%{_libdir}/alsa-lib/libasound_module_pcm_jack.so
%if %build_pulse

%files pulse
%defattr(-, root, root)
%doc COPYING
%doc doc/README-pulse
%{_libdir}/alsa-lib/libasound_module_ctl_pulse.so
%{_libdir}/alsa-lib/libasound_module_pcm_pulse.so
%{_libdir}/alsa-lib/libasound_module_conf_pulse.so
%config /etc/asound-pulse.conf
%config /etc/alsa-pulse.conf
%{_datadir}/alsa/alsa.conf.d
%endif

%files maemo
%defattr(-, root, root)
%doc COPYING
%doc doc/README-maemo
%{_libdir}/alsa-lib/libasound_module_ctl_dsp_ctl.so
%{_libdir}/alsa-lib/libasound_module_pcm_alsa_dsp.so

%files samplerate
%defattr(-, root, root)
%doc COPYING.GPL
%doc doc/samplerate.txt
%{_libdir}/alsa-lib/libasound_module_rate_samplerate*.so
%if %build_speex

%files speex
%defattr(-, root, root)
%doc COPYING
%doc doc/speexdsp.txt
%{_libdir}/alsa-lib/libasound_module_pcm_speex.so
%endif

%changelog
* Thu May 23 2013 tiwai@suse.de
- Backport upstream fixes:
  0001-Check-for-and-include-libavutil.h-to-avoid-unresolve.patch
  0002-Add-AM_MAINTAINER_MODE-enable-to-configure.in.patch
* Fri Apr 12 2013 tiwai@suse.de
- Updated to version 1.0.27:
  including all previous fixes; all 00*-* patches dropped
* Mon Mar 11 2013 tiwai@suse.de
- Backport fix patches from upstream:
  0002-a52-Add-the-support-of-recent-libavcodec-libavutil.patch
  0003-a52-Fix-build-errors.patch
  0004-pulse-pulse_pcm_poll_revents-should-return-0-on-succ.patch
* Fri Feb  1 2013 tiwai@suse.de
- Correct the package version number to 1.0.26; no content change
* Fri Nov 30 2012 tiwai@suse.de
- Improve prebuf setup of pulse plugin:
  0001-pcm_pulse-set-prebuf-parameter-according-to-software.patch
* Fri Oct 26 2012 tiwai@suse.de
- remove obsoleted alsa-plugins-include.patch
* Fri Sep  7 2012 tiwai@suse.de
- Updated to version 1.0.26:
  including glibc-2.16 build fix, add support 24bit format to pulse
* Thu Sep  6 2012 tiwai@suse.de
- Add post/postun hooks for pulse plugin to fix the leftover
  config path (bnc#779039)
* Sun Jul 29 2012 aj@suse.de
- Move _GNU_SOURCE before any header inclusion to fix build with glibc 2.16
* Sat Mar 31 2012 reddwarf@opensuse.org
- stop recommending -32bit packages
* Wed Jan 25 2012 tiwai@suse.de
- updated to version 1.0.25; including all previous fixes
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Tue Sep 27 2011 tiwai@suse.de
- Set CLOEXEC flag to left-over fds in pulse plugin
* Tue Sep 20 2011 tiwai@suse.de
- Install pulse plugin setup in the new config.d directory,
  use the upstream default
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Fri Aug 26 2011 tiwai@suse.de
- Fix the build of pulse plugin with a very old PA
* Fri Aug 26 2011 tiwai@suse.de
- Add a better overrun handling with the new PA API
* Mon Aug  8 2011 tiwai@suse.de
- Fix hanging applications when using jack plugin
* Wed Jul 27 2011 tiwai@suse.de
- Add PA_CONTEXT_NOAUTOSPAWN flag when fallback is set for pulse
  plugins
* Tue Jul 26 2011 tiwai@suse.de
- Add fallback option to pulse plugin
- Enable the fallback to the system-default in asound-pulse.conf
* Tue Apr 26 2011 tiwai@suse.de
- Upstream fixes:
  * Fix build of a52 plugin (not used in this package, though)
  * Fix bogus snd_pcm_avail() zero return in pulse plugin
* Mon Jan 31 2011 tiwai@suse.de
- Updated to version 1.0.24:
  * including previous fixes
  * Fix documents
* Thu Sep  2 2010 tiwai@suse.de
- Backport upstream fix:
  pulse: Add handle_underrun option
* Thu Jun 24 2010 tiwai@suse.de
- Backport upstream fix:
  pulse: Fix invalid buffer pointer return value
* Mon Apr 19 2010 tiwai@suse.de
- updated to version 1.0.23:
  * including previous fixes
* Mon Mar  8 2010 tiwai@suse.de
- Backport upstream fixes:
  * usb_stream: Check for NULL-ness before dereferencing
  * usb_stream: Allow user-set period-size and rate
* Wed Jan 27 2010 jengelh@medozas.de
- package baselibs.conf
* Fri Dec 18 2009 tiwai@suse.de
- set AUTOMAKE_JOBS for parallel automake
* Fri Dec 18 2009 tiwai@suse.de
- updated to version 1.0.22:
  * upmix 7.1 channels support
  * fixes for a53 with recent libavcodec
* Wed Sep  9 2009 tiwai@suse.de
- add recommends tags for 32bit packages (bnc#537555)
* Mon Aug 31 2009 tiwai@suse.de
- updated to version 1.0.21:
  just a version bump including previous fixes
* Fri Aug  7 2009 tiwai@suse.de
- yet another updates of pulse plugin:
  * replace manual mainloop by pa_mainloop_iterate()
  * move a couple of PCM related functions from pulse.c to pcm_pulse.c
  * get rid of redundant state variable
  * unify stream/context state checks
  * rework object destruction paths a bit
  * immediately trigger EIO when connection is dropped
* Mon Aug  3 2009 tiwai@suse.de
- update pulse plugin:
  * get rid of a number of assert()s
  * unify destruction of snd_pulse_t
  * use PA_CONTEXT_IS_GOOD where applicable
  * call pa_threaded_mainloop_wait() to handle spurious wakeups
* Thu Jul 30 2009 sbrabec@suse.cz
- alsa-plugin-pulse does not work without pulseaudio, add Requires.
* Fri Jul 17 2009 tiwai@suse.de
- fix the missing initialization of OSS PCM plugin
* Fri Jun 19 2009 tiwai@suse.de
- echo-cancelling support in speex dsp plugin
* Tue Jun  2 2009 tiwai@suse.de
- extend rate plugins to follow the new protocol
* Wed May  6 2009 tiwai@suse.de
- updated to version 1.0.20:
  * including previous patches
  * arcam-av plugin updates
* Tue Feb 17 2009 tiwai@suse.de
- add the support of non-zero numid in external ctl plugins
  (bnc#462032)
* Thu Jan 22 2009 tiwai@suse.de
- updated to version 1.0.19:
  * just minor updates
- added speex pre-processing plugin
- added arcam-av control plugin
- fix spec file to be compatible with older distro
* Wed Oct 29 2008 tiwai@suse.de
- updated to version 1.0.18-final;
  just including all previous fixes
* Wed Oct 15 2008 tiwai@suse.de
- Fix pulse plugin issues:
  * broken capture returning -EIO (bnc#435058)
  * small memory leak
* Wed Sep 10 2008 tiwai@suse.de
- updated to version 1.0.18rc3:
  * code cleanup in pulse pcm plugin
  * fix poll handling in pulse pcm
  * fix S32/FLOAT32 format support in pulse
  * use PA_STREAM_EARLY_REQUEST
  * fix channel mappings, buffer metrics
* Tue Aug 26 2008 tiwai@suse.de
- fix build with recent ffmpeg
* Mon Aug 18 2008 tiwai@suse.de
- updated to version 1.0.18-rc2:
  including previous fixes and additions
* Wed Aug  6 2008 tiwai@suse.de
- updated to git snapshot 20080806:
  * added usb-stream PCM plugin for US122L devices
- add config tag to pulse-related config files
* Mon Jul 28 2008 tiwai@suse.de
- fix slient output of short streams (bnc#409645)
* Wed Jul 16 2008 tiwai@suse.de
- don't use assert() for sanity checks (bnc#409532)
* Tue Jul 15 2008 tiwai@suse.de
- updated to version 1.0.17-final:
  * just a version bump
* Wed Jun 18 2008 tiwai@suse.de
- updated to version 1.0.17rc2:
  * including last fixes
* Fri Jun  6 2008 tiwai@suse.de
- use plug layer for pulse defult PCM (bnc#397523)
  this requires the fix in alsa-lib, too
* Wed Jun  4 2008 rodrigo@suse.de
- Added alsa-pulse.conf as configuration file for GNOME installs
  (bnc#394177)
* Mon Jun  2 2008 meissner@suse.de
- added baselibs.conf, so 32bit programs get the pulse-alsa
  wrapper plugin too.
* Mon May 26 2008 rodrigo@suse.de
- Removed dependency on pulseaudio, pulseaudio package now depends
  on alsa-plugins-pulse to fix bnc#394177
* Mon May 26 2008 rodrigo@suse.de
- Added asound-pulse.conf to contain configuration for the ALSA
  PulseAudio plugin (bnc#394177)
* Mon Mar 10 2008 tiwai@suse.de
- remove some useless asserts in pulse plugin that cause crashes
* Fri Feb  8 2008 tiwai@suse.de
- updated to version 1.0.16-final:
  * just a version bump
* Tue Jan 22 2008 tiwai@suse.de
- updated to version 1.0.16rc1:
  * just a version bump
* Fri Jan 11 2008 rodrigo@suse.de
- Depend on libpulse-devel, not pulseaudio-devel
* Fri Dec 14 2007 tiwai@suse.de
- several bug fixes for pulse plugin
  * fix buffer size handling
  * handle XRUN properly (requireing the latest alsa-lib)
* Mon Oct 29 2007 tiwai@suse.de
- fix invalid assert call in pulse plugin
* Tue Oct 16 2007 tiwai@suse.de
- updated to version 1.0.15:
  * including all previous fixes
* Tue Aug 14 2007 tiwai@suse.de
- Fix speex resampler plugin bugs
* Mon Jul 30 2007 tiwai@suse.de
- HG patch (as of 2007.07.28)
  * build modules with -no-undefined option
  * fix speex resampler bug in 4times upsampling
  * fix the noise at beginning of playback with samplerate
    plugin
* Tue Jun  5 2007 tiwai@suse.de
- updated to version 1.0.14-final:
  including previous HG fixes
* Thu May 24 2007 tiwai@suse.de
- HG snapshot as of 2007.05.24:
  * configure option to specify plugin directory
  * possible to link with external libspeex
* Wed May  2 2007 tiwai@suse.de
- updated to version 1.0.14rc4:
  including HG fixes
* Tue Apr 10 2007 tiwai@suse.de
- split samplerate to subpackage (the sole GPL-only module).
- fixed licenses on PDB.
* Tue Apr  3 2007 tiwai@suse.de
- Add explicitly jack and pulseaudio to Requires of each sub
  package.
* Wed Mar 14 2007 tiwai@suse.de
- updated to version 1.0.14rc3:
  * fix input/output_frames calculation in samplerate plugin
  * added speex rsampler plugin
* Thu Feb  8 2007 tiwai@suse.de
- update to version 1.0.14rc2 - just repackaging from 1.0.14rc1a
- split internal sub package to its own spec file
* Tue Dec 19 2006 tiwai@suse.de
- updated to version 1.0.14rc1:
  * clean up polyp plugin
  * added maemo plugin
- add conditional for internal build (#224415)
* Fri Aug  4 2006 tiwai@suse.de
- updated to version 1.0.12rc2:
  the previous patches were merged to upstream
* Wed Jul 12 2006 tiwai@suse.de
- rename from polyp to pulse plugin, as polypaudio is renamed
  to pulseaudio.
* Tue Jul  4 2006 tiwai@suse.de
- updated to version 1.0.12rc1:
  the previous HG patches were merged
* Thu Jun  8 2006 tiwai@suse.de
- new plugins: polyp and a52
- split to sub-packages: jack, polyp and a52
* Mon May 15 2006 tiwai@suse.de
- updated to version 1.0.11.
  * new samplerate plugins
  * misc bugfixes for JACK plugins
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Dec 14 2005 tiwai@suse.de
- updated to 1.0.10-final.
* Wed Oct 12 2005 tiwai@suse.de
- removed glib* from neededforbuild.
* Wed Oct 12 2005 tiwai@suse.de
- updated to version 1.0.10rc1.
* Thu Jun  2 2005 tiwai@suse.de
- initial version: 1.0.9.
